#
# spec file for package yambar
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yambar
Version:        1.11.0
Release:        1.5
Summary:        Modular statusbar for X11 and Wayland
License:        MIT
Group:          System/GUI/Other
URL:            https://codeberg.org/dnkl/yambar
Source:         %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz.sig
# https://keyserver.ubuntu.com/pks/lookup?op=get&search=0xb19964fbba09664cc81027ed5bbd4992c116573f
Source2:        %{name}.keyring
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  meson >= 0.59
BuildRequires:  ninja
BuildRequires:  pkg-config
BuildRequires:  scdoc
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fcft) < 4.0.0
BuildRequires:  pkgconfig(fcft) >= 3.0.0
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libmpdclient)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(tllist) >= 1.0.1
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-aux)
BuildRequires:  pkgconfig(xcb-cursor)
BuildRequires:  pkgconfig(xcb-errors)
BuildRequires:  pkgconfig(xcb-event)
BuildRequires:  pkgconfig(xcb-ewmh)
BuildRequires:  pkgconfig(xcb-proto)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(yaml-0.1)

%description
Simplistic and highly configurable status panel for X and Wayland.

%prep
%autosetup

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}
BuildArch:      noarch

%description devel
Modules for interacting and modifying yambar.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%name and zsh)
Requires:       zsh
BuildArch:      noarch

%description zsh-completion
Zsh command-line completion support for %{name}.

%build
%{meson} -Db_lto=true -Dbackend-x11=enabled -Dbackend-wayland=enabled
%{meson_build}

%install
%{meson_install}

# We remove this because the docs are supplemented already
# from the doc and license macros
rm -rfv %{buildroot}%{_datadir}/doc/

%files
%{_mandir}/man1/yambar.1%{?ext_man}
%{_mandir}/man5/yambar.5%{?ext_man}
%{_mandir}/man5/yambar-decorations.5%{?ext_man}
%{_mandir}/man5/yambar-modules.5%{?ext_man}
%{_mandir}/man5/yambar-modules-alsa.5%{?ext_man}
%{_mandir}/man5/yambar-modules-backlight.5%{?ext_man}
%{_mandir}/man5/yambar-modules-battery.5%{?ext_man}
%{_mandir}/man5/yambar-modules-clock.5%{?ext_man}
%{_mandir}/man5/yambar-modules-cpu.5%{?ext_man}
%{_mandir}/man5/yambar-modules-disk-io.5%{?ext_man}
%{_mandir}/man5/yambar-modules-dwl.5%{?ext_man}
%{_mandir}/man5/yambar-modules-foreign-toplevel.5%{?ext_man}
%{_mandir}/man5/yambar-modules-i3.5%{?ext_man}
%{_mandir}/man5/yambar-modules-label.5%{?ext_man}
%{_mandir}/man5/yambar-modules-mem.5%{?ext_man}
%{_mandir}/man5/yambar-modules-mpd.5%{?ext_man}
%{_mandir}/man5/yambar-modules-network.5%{?ext_man}
%{_mandir}/man5/yambar-modules-pipewire.5%{?ext_man}
%{_mandir}/man5/yambar-modules-pulse.5%{?ext_man}
%{_mandir}/man5/yambar-modules-removables.5%{?ext_man}
%{_mandir}/man5/yambar-modules-river.5%{?ext_man}
%{_mandir}/man5/yambar-modules-script.5%{?ext_man}
%{_mandir}/man5/yambar-modules-sway.5%{?ext_man}
%{_mandir}/man5/yambar-modules-sway-xkb.5%{?ext_man}
%{_mandir}/man5/yambar-modules-xkb.5%{?ext_man}
%{_mandir}/man5/yambar-particles.5%{?ext_man}
%{_mandir}/man5/yambar-tags.5%{?ext_man}

%{_bindir}/yambar
%{_datadir}/applications/yambar.desktop
%{_datadir}/zsh/site-functions/_yambar

%license LICENSE
%doc README.md CHANGELOG.md

%files devel
%dir %{_includedir}/%{name}/
%dir %{_includedir}/%{name}/bar
%{_includedir}/%{name}/bar/bar.h
%{_includedir}/%{name}/color.h
%{_includedir}/%{name}/config-verify.h
%{_includedir}/%{name}/config.h
%{_includedir}/%{name}/decoration.h
%{_includedir}/%{name}/log.h
%{_includedir}/%{name}/module.h
%{_includedir}/%{name}/particle.h
%{_includedir}/%{name}/stride.h
%{_includedir}/%{name}/tag.h
%{_includedir}/%{name}/xcb.h
%{_includedir}/%{name}/yml.h

%changelog
* Mon Apr 22 2024 Joshua Smith <smolsheep@opensuse.org>
- Add keyring and signature for package.
- Update to 1.11.0:
  Added:
  * battery: current smoothing, for improved discharge estimates.
  * battery: scale option, for batteries that report 'charge' at a
    different scale than 'current'.
  * network: new quality tag (Wi-Fi only).
  * Read alternative config from pipes and FIFOs (e.g. --config
    /dev/stdin).
  * Added overlay and background as possible layer values.
  Changed:
  * log-level: default to warning
  * network: use dynlist instead of fixed name
  Fixed:
  * Compiler error ‘fmt’ may be used uninitialized.
  * map: conditions failing to match when they contain multiple,
    quoted tag values.
  * Crash when hidden by an opaque window.
  * Bar not resizing itself when the screen resolution is changed.
  * i3/sway: incorrect empty/title state of workspaces.
  * mem: state updated on each bar redraw.
  * script: buffer overflow when reading large amounts of data.
  * i3/sway: module fails when reloading config file.
  * Worked around bug in gcc causing a compilation error.
  * Miscalculation of list width in presence of empty particles.
  * Log-level not respected by syslog.
* Thu Jul 20 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove _service file
- Update to version 1.10.0
  * Field width tag format option
  * river: support for ‘layout’ events.
  * dwl: support for specifying name of tags
  * i3/sway: extend option sort; use native to sort numbered workspaces only.
  * modules/dwl: handle the appid status
  * battery: also show estimation for time to full
  * on-click: tilde expansion
  * script: tilde expansion of path.
  * disk-io: interval renamed to poll-interval
  * mem: interval renamed to poll-interval
  * battery/network/script: poll-interval unit changed from seconds to milliseconds.
  * all modules: minimum poll interval changed from 500ms to 250ms.
  * network: do not use IPv6 link-local
  * Build failures for certain combinations of enabled and disabled plugins.
  * Documentation for the cpu module; interval has been renamed to poll-interval.
  * battery: module was not thread safe.
  * dwl module reporting only the last part of the title
  * i3/sway: regression; persistent workspaces shown twice.
  * pipewire: use roundf() instead of ceilf() for more accuracy
  * Crash when a yaml anchor has a value that already exists in the target yaml node.
  * battery: Fix time conversion in battery estimation
  * battery: poll timeout being reset when receiving irrelevant udev notification (leading to battery status never updating, in worst case).
* Mon Jan 23 2023 socvirnyl.estela@gmail.com
- Update to version 1.9.0+g34:
  * module/dwl: allow specify the name of tags
  * CHANGELOG.md: add issue #262
  * modules/pipewire: change type of volume from uint8 to uint16
  * modules/pipewire: use roundf instead of ceilf for more accuracy
  * module/river: add support for ‘layout’ events
* Fri Jan 13 2023 socvirnyl.estela@gmail.com
- Update to version 1.9.0+g28:
  * module/pipewire: handle failures when trying to connect to pipewire
  * ci: drop gitlab CI
  * tag: handle width formatter on ints when no other formatting options are used
  * doc: tags: add a couple of formatting examples
  * doc: tags: re-arrange columns in ‘formatting’ table
  * implement field width tag format option
  * module/i3: fix regression in handling of persistent workspaces
  * module/dwl: correctly handle the title
  * modules: change min poll interval from 500ms to 250ms
  * module/battery: using a static buffer in readline_from_fd() isn’t thread safe
* Tue Dec 20 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix installation of license and docs.
- Set devel to noarch.
* Mon Dec 19 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Simplify specfile and just use the defined C standard in meson config.
* Sat Dec 17 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.9.0:
  * Added
  - Support for specifying number of decimals when printing a float tag.
  - Support for custom font fallbacks.
  - overline: new decoration.
  - i3/sway: boolean option `strip-workspace-numbers`.
  - font-shaping: new inheritable configuration option, allowing you to
  - configure whether strings should be _shaped_ using HarfBuzz, or not.
  - river: support for the new “mode” event present in version 3 of the
  - river status manager protocol, in the form of a new tag, _”mode”_,
  - in the `title` particle.
  - network: request link stats and expose under tags `dl-speed` and
  - `ul-speed` when `poll-interval` is set.
  - new module: disk-io.
  - new module: pulse.
  - alsa: `dB` tag.
  - mpd: `file` tag.
  - pipewire: add a new module for pipewire
  - on-click: support `next`/`previous` mouse buttons.
  - dwl: add a new module for DWL
  - sway: support for workspace ‘rename’ and ‘move’ events.
  * Changed
  - All modules are now compile-time optional.
  - Minimum required meson version is now 0.59.
  - Float tags are now treated as floats instead of integers when
  formatted with the `kb`/`kib`/`mb`/`mib`/`gb`/`gib` string particle
  formatters.
  - network: `tx-bitrate` and `rx-bitrate` are now in bits/s instead of
  Mb/s. Use the `mb` string formatter to render these tags as before
  (e.g. `string: {text: "{tx-bitrate:mb}"}`).
  - i3: newly created, and **unfocused** workspaces are now considered
  non-empty
  - alsa: use dB instead of raw volume values, if possible, when
  calculating the `percent` tag
  - cpu: `content` particle is now a template instantiated once for each
  core, and once for the total CPU usage. See **yambar-modules-cpu**(5)
  for more information.
  - **BREAKING CHANGE**: overhaul of the `map` particle. Instead of
  specifying a `tag` and then an array of `values`, you must now
  simply use an array of `conditions`
  * Fixed
  - i3: fixed “missing workspace indicator” (_err: modules/i3.c:94:
  workspace reply/event without 'name' and/or 'output', and/or 'focus'
  properties_).
  - Slow/laggy behavior when quickly spawning many `on-click` handlers,
  e.g. when handling mouse wheel events.
  - cpu: don’t error out on systems where SMT has been disabled.
  - examples/dwl-tags: updated parsing of `output` name.
  - sway-xkb: don’t crash when Sway sends an _”added”_ event for a
  device yambar is already tracking.
  - Crash when a particle is “too wide”, and tries to render outside the
  bar.
  - string: crash when failing to convert string to UTF-32.
  - script: only first transaction processed when receiving multiple
  transactions in a single batch.
  - network: missing SSID (recent kernels, or possibly wireless drivers,
  no longer provide the SSID in the `NL80211_CMD_NEW_STATION`
  response).
  - sway-xkb: crash when compositor presents multiple inputs with
  identical IDs.
* Sat Aug 20 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- set C standard to none if suse version is 15.4
* Sat May 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix rpm lint errors on unpackaged files
* Fri May 27 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for yambar 1.8.0
